A 97.8 GOPS/W FPGA-Based Residual-Block-Aware CNN Accelerator Featuring Multi-Clock PW <sup>2</sup> Pipeline and Adaptive-Resolution Quantization
Enhancing the energy efficiency for the residual block is crucial for an energy-efficient deep neural network accelerator. This paper presents a multi-clock pointwise-pointwise (MCPW2) technique to process the adjacent PW convolution layers across residual blocks, reducing up to 75.0% DRAM access for the intermediate feature maps while securing >88.1% processing element (PE) utilization. Moreover, we introduce a dual-precision packing (DPP) DSP array to compute multiple 4/8-bit multiplications in a shared DSP, improving the accuracy by 1.5% (ImageNet) using low-precision residual distillation (RD) with adaptive-resolution quantization. The DPP DSP and adaptive-resolution RD boost the DSP efficiency up to <inline-formula xmlns:mml="http://www.w3.org/1998/Math/MathML" xmlns:xlink="http://www.w3.org/1999/xlink"> <tex-math notation="LaTeX">$4.0\times $ </tex-math></inline-formula>, reduce DRAM access by 50.0%, and improve the throughput by <inline-formula xmlns:mml="http://www.w3.org/1998/Math/MathML" xmlns:xlink="http://www.w3.org/1999/xlink"> <tex-math notation="LaTeX">$\gt 2.7\times $ </tex-math></inline-formula>. We also propose a dynamic accumulator/multiplier (A/M) DSP reconfiguration scheme to dynamically adjust the level of parallelism along the input/output channel dimensions. It also increases the PE utilization by <inline-formula xmlns:mml="http://www.w3.org/1998/Math/MathML" xmlns:xlink="http://www.w3.org/1999/xlink"> <tex-math notation="LaTeX">$1.8\times $ </tex-math></inline-formula> for the depthwise (DW) convolution layers with 33% less hardware resource overhead. Implemented on Xilinx VC709, the proposed accelerator achieves PE utilization of >93.0%, a DSP efficiency gain of <inline-formula xmlns:mml="http://www.w3.org/1998/Math/MathML" xmlns:xlink="http://www.w3.org/1999/xlink"> <tex-math notation="LaTeX">$\gt 2.9\times $ </tex-math></inline-formula>, and a throughput improvement on benchmarked networks of <inline-formula xmlns:mml="http://www.w3.org/1998/Math/MathML" xmlns:xlink="http://www.w3.org/1999/xlink"> <tex-math notation="LaTeX">$4.9\times $ </tex-math></inline-formula> while exhibiting an energy efficiency of 97.8 GOPs/W and a normalized throughput of 1.18 GOPS/DSP.
Authors
- Ka-Fai Un (ORCID: https://orcid.org/0000-0002-7574-4755)
- Pui‐In Mak (ORCID: https://orcid.org/0000-0002-3579-8740)
- Jixuan Li (ORCID: https://orcid.org/0009-0001-6615-0680)
- Wei-Han Yu (ORCID: https://orcid.org/0000-0002-9079-5227)
- Ke Li (ORCID: https://orcid.org/0000-0002-7318-1186)
- Rui P. Martins (ORCID: https://orcid.org/0000-0003-2821-648X)
Institutions
- University of Macau (MO)
- Institute of Microelectronics (CN)
Publication Details
- Journal
- IEEE Transactions on Circuits and Systems I Regular Papers
- Published
- 2024-11-27
- DOI
- https://doi.org/10.1109/tcsi.2024.3505299
- Citations
- 1
- Primary Topic
- Image Processing Techniques and Applications
- Type
- article
- Field-Weighted Citation Impact
- 0.32
Funders
- VNU Science and Technology Development Fund
- Universidade de Macau